@@ -1,5 +1,4 @@
 from __future__ import print_function
-import sys
 from difflib import SequenceMatcher
 
 
@@ -30,8 +29,10 @@ def textsim(x, y):
     sm = SequenceMatcher(lambda x: x in ". -", x, y)
     return 1 - sm.ratio()
 
-# sim = textsim
-sim = lambda x, y: abs(x-y)
+
+def simplesim(x, y):
+    return abs(x-y)
+
 
 
 def single(a, b):
@@ -50,7 +51,7 @@ def average(a, b):
     return mean([sim(ex, ey) for ex in a for ey in b])
 
 
-linkage = average
+linkage = single
 
 
 data = [['Lorem'],
@@ -73,10 +74,12 @@ data = [['Lorem'],
         ['at'],
         ['neque'],
         ['Nullam']]
+sim = textsim
 
 
 data = [[_] for _ in [791, 956, 676, 124, 564, 84, 24, 365, 594, 940, 398, 971,
                       131, 365, 542, 336, 518, 835, 134, 391]]
+sim = simplesim
 
 
 def matrix(data):
@@ -114,9 +117,9 @@ def print_matrix2(data, iteration):
         strsimdata = ['**{:.3f}**'.format(_)
                       if _ == smallest else '{:.3f}'.format(_)
                       for _ in simdata]
-        foo = ','.join([str(_) for _ in row])
-        bar = ': '.join(strsimdata)
-        print('    ' + foo, bar, sep=': ')
+        rowheader = ','.join([str(_) for _ in row])
+        rowcells = ': '.join(strsimdata)
+        print('    ' + rowheader, rowcells, sep=': ')
 
 
 i = 1
